package de.unikoblenz.fgbks.core.dmn.utils;

import de.unikoblenz.fgbks.core.dmn.domain.vdmn.VDmnDefinitions;
import java.util.List;
import org.camunda.bpm.dmn.engine.DmnDecision;
import org.camunda.bpm.model.dmn.DmnModelInstance;

/**
 * A container class for storing information about a dmn table with different formats.
 */
public class DmnObjectContainer {

  private final List<DmnDecision> dmnDecisions;
  private final DmnModelInstance dmnModel;
  private final VDmnDefinitions vDmnDefinitions;

  /**
   * Create a new Instance of the dmn object container.
   *
   * @param dmnDecisions the list of {@link DmnDecision}
   * @param dmnModel the {@link DmnModelInstance}
   * @param vDmnDefinitions the {@link VDmnDefinitions}
   */
  public DmnObjectContainer(
      List<DmnDecision> dmnDecisions, DmnModelInstance dmnModel, VDmnDefinitions vDmnDefinitions) {
    this.dmnDecisions = dmnDecisions;
    this.dmnModel = dmnModel;
    this.vDmnDefinitions = vDmnDefinitions;
  }

  /**
   * Get the list of dmn decisions.
   *
   * @return the list of {@link DmnDecision}
   */
  public List<DmnDecision> getDmnDecisions() {
    return dmnDecisions;
  }

  /**
   * Get the dmn model.
   *
   * @return the {@link DmnModelInstance}
   */
  public DmnModelInstance getDmnModel() {
    return dmnModel;
  }

  /**
   * Get the VDmnDefinition.
   *
   * @return the {@link VDmnDefinitions}
   */
  public VDmnDefinitions getVDmnDefinition() {
    return vDmnDefinitions;
  }
}
