package de.unikoblenz.fgbks.core.dmn.verification.verifier.config;

import de.unikoblenz.fgbks.base.builder.DefaultBuilder;
import de.unikoblenz.fgbks.core.dmn.utils.DmnObjectContainer;
import de.unikoblenz.fgbks.core.dmn.verification.result.actions.FixActionService;
import java.util.concurrent.ConcurrentHashMap;
import org.apache.commons.lang3.Validate;

public class DefaultConfiguration extends AbstractDmnVerifierConfig {

  public static final String KEY_DMN_OBJECT_CONTAINER = "dmnDecisions";
  public static final String KEY_FIX_ACTIONS = "fixActionsConfig";
  public static final String KEY_SHARED_MAP = "sharedMap";

  protected DefaultConfiguration() {
    super.withConfigurationProperty(KEY_SHARED_MAP, new ConcurrentHashMap<>(1024));
  }

  public static Builder getBuilder() {
    return new DefaultConfiguration().new Builder();
  }

  public class Builder extends DefaultBuilder<DefaultConfiguration> {

    public Builder withDmnObjectContainer(DmnObjectContainer dmnObjectContainer) {
      value.withConfigurationProperty(KEY_DMN_OBJECT_CONTAINER, dmnObjectContainer);
      return this;
    }

    public Builder withVerificationProcessId(long verificationProcessId) {
      value.verificationProcessId = verificationProcessId;
      return this;
    }

    public Builder withFixActionService(FixActionService fixActionService) {
      value.withConfigurationProperty(KEY_FIX_ACTIONS, fixActionService);
      value.verificationProcessId = verificationProcessId;
      return this;
    }

    @Override
    protected void validate() {
      super.validate();
      Validate.notNull(value.getConfiguration(KEY_DMN_OBJECT_CONTAINER));
      Validate.isInstanceOf(
          DmnObjectContainer.class, value.getConfiguration(KEY_DMN_OBJECT_CONTAINER));
    }
  }
}
